@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-val.h :
  *
@@ -23,8 +22,8 @@
 #ifndef GO_VAL_H
 #define GO_VAL_H
 
-#include "value.h"	/* remove after move to goffice */
-#include "gnm-format.h"	/* remove after move to goffice */
+#include <value.h>	/* remove after move to goffice */
+#include <gnm-format.h>	/* remove after move to goffice */
 
 G_BEGIN_DECLS
 #ifndef GOFFICE_NAMESPACE_DISABLE
