@@ -1,15 +1,13 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_OBJECT_IMPL_H_
 # define _GNM_SHEET_OBJECT_IMPL_H_
 
 G_BEGIN_DECLS
 
-#include "sheet-object.h"
+#include <sheet-object.h>
 #include <goffice/goffice.h>
 #include <gsf/gsf-libxml.h>
 #include <libxml/tree.h>
 #include <glib-object.h>
-#include <gtk/gtk.h>
 
 typedef enum {
 	SHEET_OBJECT_IS_VISIBLE	= 1 << 0,	/* user selectable */
@@ -54,15 +52,15 @@ typedef struct {
 	void (*signal_pad2)	(void);
 
 	/* Virtual methods */
-	gboolean (*remove_from_sheet) (SheetObject	*sheet_object);
-	gboolean   (*assign_to_sheet) (SheetObject	*sheet_object,
+	gboolean (*remove_from_sheet) (SheetObject	*so);
+	gboolean   (*assign_to_sheet) (SheetObject	*so,
 				       Sheet		*sheet);
 
-	SheetObjectView	*(*new_view) (SheetObject	*sheet_object,
+	SheetObjectView	*(*new_view) (SheetObject	*so,
 				      SheetObjectViewContainer *container);
 	void        (*populate_menu) (SheetObject	*so,
 				      GPtrArray		*actions);
-	void	      (*user_config) (SheetObject	*sheet_object,
+	void	      (*user_config) (SheetObject	*so,
 				      SheetControl	*s_control);
 	void      (*prep_sax_parser) (SheetObject *so,
 				      GsfXMLIn *xin, xmlChar const **attrs,
@@ -105,7 +103,7 @@ typedef struct {
 	void *data_pad3;
 	void *data_pad4;
 } SheetObjectClass;
-#define SHEET_OBJECT_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), SHEET_OBJECT_TYPE, SheetObjectClass))
+#define GNM_SO_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GNM_SO_TYPE, SheetObjectClass))
 
 /***************************************************************************/
 
@@ -123,18 +121,19 @@ typedef struct {
 			    double const *coords, gboolean visible);
 } SheetObjectViewClass;
 
-#define SHEET_OBJECT_VIEW_TYPE		(sheet_object_view_get_type ())
-#define SHEET_OBJECT_VIEW(o)		(G_TYPE_CHECK_INSTANCE_CAST((o), SHEET_OBJECT_VIEW_TYPE, SheetObjectView))
-#define IS_SHEET_OBJECT_VIEW(o)		(G_TYPE_CHECK_INSTANCE_TYPE((o), SHEET_OBJECT_VIEW_TYPE))
-#define SHEET_OBJECT_VIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), SHEET_OBJECT_VIEW_TYPE, SheetObjectViewIface))
-#define IS_SHEET_OBJECT_VIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE((k), SHEET_OBJECT_VIEW_TYPE))
-#define SHEET_OBJECT_VIEW_GET_CLASS(o)  (G_TYPE_INSTANCE_GET_CLASS ((o), SHEET_OBJECT_VIEW_TYPE, SheetObjectViewClass))
+#define GNM_SO_VIEW_TYPE		(sheet_object_view_get_type ())
+#define GNM_SO_VIEW(o)		(G_TYPE_CHECK_INSTANCE_CAST((o), GNM_SO_VIEW_TYPE, SheetObjectView))
+#define GNM_IS_SO_VIEW(o)		(G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_SO_VIEW_TYPE))
+#define GNM_SO_VIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GNM_SO_VIEW_TYPE, SheetObjectViewIface))
+#define GNM_IS_SO_VIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE((k), GNM_SO_VIEW_TYPE))
+#define GNM_SO_VIEW_GET_CLASS(o)  (G_TYPE_INSTANCE_GET_CLASS ((o), GNM_SO_VIEW_TYPE, SheetObjectViewClass))
 
 GType	     sheet_object_view_get_type	  (void);
 SheetObject *sheet_object_view_get_so	  (SheetObjectView *sov);
 void	     sheet_object_view_set_bounds (SheetObjectView *sov,
 					   double const *coords,
 					   gboolean visible);
+GocItem     *sheet_object_view_get_item   (SheetObjectView *sov);
 
 /***************************************************************************/
 
