@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_STYLE_FONT_H_
 # define _GNM_STYLE_FONT_H_
 
-#include "gnumeric.h"
-#include "libgnumeric.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
 #include <pango/pango.h>
 
 G_BEGIN_DECLS
@@ -12,7 +11,7 @@ struct _GnmFont {
 	int	 ref_count;
 	char	*font_name;
 	double	 size_pts;
-	struct {
+	struct _GnmGOFont {
 		GOFont const *font;
 		GOFontMetrics *metrics;
 	} go;
@@ -22,10 +21,11 @@ struct _GnmFont {
 	unsigned int is_italic : 1;
 };
 
+GType    gnm_font_get_type (void);
 GnmFont *gnm_font_new   (PangoContext *context,
 			 char const *font_name,
 			 double size_pts, gboolean bold, gboolean italic);
-void     gnm_font_ref   (GnmFont *gfont);
+GnmFont *gnm_font_ref   (GnmFont *gfont);
 void     gnm_font_unref (GnmFont *gfont);
 guint    gnm_font_hash  (gconstpointer v);
 gint     gnm_font_equal (gconstpointer v, gconstpointer v2);
