@@ -15,9 +15,9 @@
 #ifndef GNUMERIC_TOOLS_H
 #define GNUMERIC_TOOLS_H
 
-#include "gnumeric.h"
-#include "numbers.h"
-#include "dao.h"
+#include <gnumeric.h>
+#include <numbers.h>
+#include <tools/dao.h>
 
 typedef enum {
 	TOOL_ENGINE_UPDATE_DAO = 0,
